Transport

Trait Transport 

pub trait Transport:
    AsyncRead
    + AsyncWrite
    + Send
    + Unpin { }
Async bidirectional byte stream for talking to an MMDVM modem.

Blanket-implemented for any type that is both [AsyncRead] + [AsyncWrite] + Send + Unpin. See mmdvm_core for the wire-format specifics the bytes on this stream must follow.

Implementors

Source

impl<T: AsyncRead + AsyncWrite + Send + Unpin> Transport for T