pub trait Transport:
AsyncRead
+ AsyncWrite
+ Send
+ Unpin { }Expand description
Async bidirectional byte stream for talking to an MMDVM modem.
Blanket-implemented for any type that is both [AsyncRead] +
[AsyncWrite] + Send + Unpin. See mmdvm_core for the
wire-format specifics the bytes on this stream must follow.